@@ -1,7 +1,7 @@
 import json
 import redis
 
-from rosetta_dispatcher import idtool
+from rosetta_dispatcher.idtool import idtool
 from rosetta_dispatcher.model.dispatch_response_model import DispatchResponseModel
 from rosetta_dispatcher.model.dispatch_types import DispatchRequestType, DispatchResponseStatus
 
